# PyFixest Function Reference {.doc .doc-index}

## Estimation Functions

User facing estimation functions


| | |
| --- | --- |
| [estimation.estimation.feols](estimation.estimation.feols.qmd#pyfixest.estimation.estimation.feols) | Estimate a linear regression models with fixed effects using fixest formula syntax. |
| [estimation.estimation.fepois](estimation.estimation.fepois.qmd#pyfixest.estimation.estimation.fepois) | Estimate Poisson regression model with fixed effects using the `ppmlhdfe` algorithm. |
| [estimation.estimation.feglm](estimation.estimation.feglm.qmd#pyfixest.estimation.estimation.feglm) | Estimate GLM regression model with fixed effects. |
| [did.estimation.did2s](did.estimation.did2s.qmd#pyfixest.did.estimation.did2s) | Estimate a Difference-in-Differences model using Gardner's two-step DID2S estimator. |
| [did.estimation.lpdid](did.estimation.lpdid.qmd#pyfixest.did.estimation.lpdid) | Local projections approach to estimation. |
| [did.estimation.event_study](did.estimation.event_study.qmd#pyfixest.did.estimation.event_study) | Estimate Event Study Model. |
| [estimation.bonferroni](estimation.bonferroni.qmd#pyfixest.estimation.bonferroni) | Compute Bonferroni adjusted p-values for multiple hypothesis testing. |
| [estimation.rwolf](estimation.rwolf.qmd#pyfixest.estimation.rwolf) | Compute Romano-Wolf adjusted p-values for multiple hypothesis testing. |

## Estimation Classes

Details on Methods and Attributes


| | |
| --- | --- |
| [estimation.feols_.Feols](estimation.feols_.Feols.qmd#pyfixest.estimation.feols_.Feols) | Non user-facing class to estimate a linear regression via OLS. |
| [estimation.fepois_.Fepois](estimation.fepois_.Fepois.qmd#pyfixest.estimation.fepois_.Fepois) | Estimate a Poisson regression model. |
| [estimation.feiv_.Feiv](estimation.feiv_.Feiv.qmd#pyfixest.estimation.feiv_.Feiv) | Non user-facing class to estimate an IV model using a 2SLS estimator. |
| [estimation.feglm_.Feglm](estimation.feglm_.Feglm.qmd#pyfixest.estimation.feglm_.Feglm) | Abstract base class for the estimation of a fixed-effects GLM model. |
| [estimation.felogit_.Felogit](estimation.felogit_.Felogit.qmd#pyfixest.estimation.felogit_.Felogit) | Class for the estimation of a fixed-effects logit model. |
| [estimation.feprobit_.Feprobit](estimation.feprobit_.Feprobit.qmd#pyfixest.estimation.feprobit_.Feprobit) | Class for the estimation of a fixed-effects probit model. |
| [estimation.fegaussian_.Fegaussian](estimation.fegaussian_.Fegaussian.qmd#pyfixest.estimation.fegaussian_.Fegaussian) | Class for the estimation of a fixed-effects GLM with normal errors. |
| [estimation.feols_compressed_.FeolsCompressed](estimation.feols_compressed_.FeolsCompressed.qmd#pyfixest.estimation.feols_compressed_.FeolsCompressed) | Non-user-facing class for compressed regression with fixed effects. |

## Summarize and Visualize

Post-Processing of Estimation Results


| | |
| --- | --- |
| [did.visualize.panelview](did.visualize.panelview.qmd#pyfixest.did.visualize.panelview) | Generate a panel view of the treatment variable over time for each unit. |
| [report.summary](report.summary.qmd#pyfixest.report.summary) | Print a summary of estimation results for each estimated model. |
| [report.etable](report.etable.qmd#pyfixest.report.etable) | Create an esttab-like table from a list of models. |
| [report.dtable](report.dtable.qmd#pyfixest.report.dtable) | Generate descriptive statistics tables and create a booktab style table in |
| [report.coefplot](report.coefplot.qmd#pyfixest.report.coefplot) | Plot model coefficients with confidence intervals. |
| [report.iplot](report.iplot.qmd#pyfixest.report.iplot) | Plot model coefficients for variables interacted via "i()" syntax, with |
| [did.visualize.panelview](did.visualize.panelview.qmd#pyfixest.did.visualize.panelview) | Generate a panel view of the treatment variable over time for each unit. |

## Misc / Utilities

PyFixest internals and utilities


| | |
| --- | --- |
| [estimation.demean](estimation.demean.qmd#pyfixest.estimation.demean) | Demean an array. |
| [estimation.detect_singletons](estimation.detect_singletons.qmd#pyfixest.estimation.detect_singletons) | Detect singleton fixed effects in a dataset. |
| [estimation.model_matrix_fixest](estimation.model_matrix_fixest.qmd#pyfixest.estimation.model_matrix_fixest) | Create model matrices for fixed effects estimation. |